@@ -639,7 +639,7 @@ gboolean gw_obex_cb(GIOChannel *chan, GIOCondition cond, gpointer data) {
         GW_OBEX_UNLOCK(ctx);
         if (ctx->xfer && ctx->xfer->cb)
             ctx->xfer->cb(ctx->xfer, ctx->xfer->cb_data);
-        if (ctx->dc_cb)
+	else if (ctx->dc_cb)
             ctx->dc_cb(ctx, ctx->dc_data);
         return FALSE;
     }
